@@ -76,6 +76,9 @@
 /* Sun IRIG audio decoder */
 #undef CLOCK_IRIG
 
+/* JJY receiver */
+#undef CLOCK_JJY
+
 /* Rockwell Jupiter GPS clock */
 #undef CLOCK_JUPITER
 
@@ -396,6 +399,9 @@
 /* hstrerror()? */
 #undef DECL_HSTRERROR_0
 
+/* inet_ntoa()? */
+#undef DECL_INET_NTOA_0
+
 /* ioctl()? */
 #undef DECL_IOCTL_0
 
