@@ -364,7 +364,7 @@ struct peer {
 /*
  * Values for peer.stratum, sys_stratum
  */
-#define	STRATUM_REFCLOCK ((u_char)0) /* stratum claimed by primary clock */
+#define	STRATUM_REFCLOCK ((u_char)0) /* default stratum */
 /* A stratum of 0 in the packet is mapped to 16 internally */
 #define	STRATUM_PKT_UNSPEC ((u_char)0) /* unspecified in packet */
 #define	STRATUM_UNSPEC	((u_char)16) /* unspecified */
@@ -447,7 +447,8 @@ struct peer {
 #define REFCLK_FG		37	/* Forum Graphic GPS */
 #define REFCLK_HOPF_SERIAL	38	/* hopf DCF77/GPS serial line receiver  */
 #define REFCLK_HOPF_PCI		39	/* hopf DCF77/GPS PCI receiver  */
-#define REFCLK_MAX		39	/* Grow as needed... */
+#define REFCLK_JJY		40	/* JJY receiver  */
+#define REFCLK_MAX		40	/* Grow as needed... */
 
 /*
  * We tell reference clocks from real peers by giving the reference
