@@ -24,7 +24,9 @@
 
 #include <stdio.h>
 #include <ctype.h>
+#ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
+#endif
 #include <signal.h>
 #ifndef SIGCHLD
 # define SIGCHLD SIGCLD
@@ -79,8 +81,8 @@ extern int priority_done;
  * setvar [ ]
  * logfile logfile
  * logconfig [+|-|=][{sync|sys|peer|clock}{{,all}{info|statistics|events|status}}]...
- * enable auth|bclient|pll|kernel|monitor|stats
- * disable auth|bclient|pll|kernel|monitor|stats
+ * enable auth|bclient|pll|kernel|monitor|stats|calibrate
+ * disable auth|bclient|pll|kernel|monitor|stats|calibrate
  * phone ...
  * pps device [assert|clear] [hardpps]
  * priority high|normal
@@ -240,12 +242,12 @@ static	struct keyword fgen_types[] = {
 static struct keyword flags_keywords[] = {
 	{ "auth",		PROTO_AUTHENTICATE },
 	{ "bclient",		PROTO_BROADCLIENT },
+	{ "calibrate",		PROTO_CAL },
 	{ "kernel",		PROTO_KERNEL },
 	{ "monitor",		PROTO_MONITOR },
 	{ "ntp",		PROTO_NTP },
-	{ "stats",		PROTO_FILEGEN },
 	{ "pps",		PROTO_PPS },
-	{ "calibrate",		PROTO_CAL },
+	{ "stats",		PROTO_FILEGEN },
 	{ "",			CONFIG_UNKNOWN }
 };
 
@@ -2096,11 +2098,11 @@ save_resolve(
 	}
 #endif
 
-	(void)fprintf(res_fp, "%s %d %d %d %d %d %d %d %s\n", name,
+	(void)fprintf(res_fp, "%s %d %d %d %d %d %d %u %s\n", name,
 	    mode, version, minpoll, maxpoll, flags, ttl, keyid, keystr);
 #ifdef DEBUG
 	if (debug > 1)
-		printf("config: %s %d %d %d %d %x %d %08x %s\n", name, mode,
+		printf("config: %s %d %d %d %d %x %d %u %s\n", name, mode,
 		    version, minpoll, maxpoll, flags, ttl, keyid, keystr);
 #endif
 
