@@ -396,6 +396,7 @@ static u_char clocktypes[] = {
 	CTL_SST_TS_LF,		/* REFCLK_FG (37) */
 	CTL_SST_TS_UHF, 	/* REFCLK_HOPF_SERIAL (38) */
 	CTL_SST_TS_UHF,		/* REFCLK_HOPF_PCI (39) */
+	CTL_SST_TS_LF,		/* REFCLK_JJY (40) */
 };
 
 
@@ -1466,16 +1467,20 @@ ctl_putpeer(
 		break;
 
 	case CP_REFID:
-		if (peer->stratum > 1) {
-			if (peer->flags & FLAG_REFCLOCK)
-			    ctl_putadr(peer_var[CP_REFID].text,
-			        peer->srcadr.sin_addr.s_addr);
-			else
+		if (peer->flags & FLAG_REFCLOCK) {
+			if (peer->stratum > 0)
 			    ctl_putadr(peer_var[CP_REFID].text,
 			        peer->refid);
+			else
+			    ctl_putid(peer_var[CP_REFID].text,
+			        (char *)&peer->refid);
 		} else {
-			ctl_putid(peer_var[CP_REFID].text,
-			    (char *)&peer->refid);
+			if (peer->stratum > 1)
+			    ctl_putadr(peer_var[CP_REFID].text,
+				peer->refid);
+			else
+			    ctl_putid(peer_var[CP_REFID].text,
+				(char *)&peer->refid);
 		}
 		break;
 
