@@ -516,7 +516,7 @@ findhostaddr(
 			msyslog(LOG_INFO, "findhostaddr: address resolved.");
 #endif
 		s = strlen(hp->h_name) + 1;
-		cp = (char *)emalloc(s);
+		cp = emalloc(s);
 		strcpy(cp, hp->h_name);
 		entry->ce_name = cp;
 	}
@@ -711,8 +711,7 @@ request(
 
 		if (n < 0)
 		{
-			if (errno != EINTR)
-			    msyslog(LOG_ERR, "select() fails: %m");
+			msyslog(LOG_ERR, "select() fails: %m");
 			return 0;
 		}
 		else if (n == 0)
@@ -833,32 +832,32 @@ request(
 		
 		    case INFO_ERR_IMPL:
 			msyslog(LOG_ERR,
-				"ntpd reports implementation mismatch!");
+				"server reports implementation mismatch!!");
 			return 0;
 		
 		    case INFO_ERR_REQ:
 			msyslog(LOG_ERR,
-				"ntpd says configuration request is unknown!");
+				"server claims configuration request is unknown");
 			return 0;
 		
 		    case INFO_ERR_FMT:
 			msyslog(LOG_ERR,
-				"ntpd indicates a format error occurred!");
+				"server indicates a format error occurred(!!)");
 			return 0;
 
 		    case INFO_ERR_NODATA:
 			msyslog(LOG_ERR,
-				"ntpd indicates no data available!");
+				"server indicates no data available (shouldn't happen)");
 			return 0;
 		
 		    case INFO_ERR_AUTH:
 			msyslog(LOG_ERR,
-				"ntpd returns a permission denied error!");
+				"server returns a permission denied error");
 			return 0;
 
 		    default:
 			msyslog(LOG_ERR,
-				"ntpd returns unknown error code %d!", n);
+				"server returns unknown error code %d", n);
 			return 0;
 		}
 	}
