@@ -217,10 +217,8 @@ refclock_newpeer(
 	peer->refclktype = clktype;
 	peer->refclkunit = unit;
 	peer->flags |= FLAG_REFCLOCK;
-	peer->stratum = STRATUM_REFCLOCK;
-	peer->refid = peer->srcadr.sin_addr.s_addr;
 	peer->maxpoll = peer->minpoll;
-
+	peer->stratum = STRATUM_REFCLOCK;
 	pp->type = clktype;
 	pp->timestarted = current_time;
 
@@ -228,12 +226,11 @@ refclock_newpeer(
 	 * Set peer.pmode based on the hmode. For appearances only.
 	 */
 	switch (peer->hmode) {
-
-		case MODE_ACTIVE:
+	case MODE_ACTIVE:
 		peer->pmode = MODE_PASSIVE;
 		break;
 
-		default:
+	default:
 		peer->pmode = MODE_SERVER;
 		break;
 	}
@@ -248,10 +245,7 @@ refclock_newpeer(
 	}
 	peer->hpoll = peer->minpoll;
 	peer->ppoll = peer->maxpoll;
-	if (peer->stratum <= 1)
-		peer->refid = pp->refid;
-	else
-		peer->refid = peer->srcadr.sin_addr.s_addr;
+	peer->refid = pp->refid;
 	return (1);
 }
 
@@ -989,10 +983,11 @@ refclock_control(
 		if (in->haveflags & CLK_HAVETIME2)
 			pp->fudgetime2 = in->fudgetime2;
 		if (in->haveflags & CLK_HAVEVAL1)
-			peer->stratum = (u_char) in->fudgeval1;
+			pp->stratum = (u_char) in->fudgeval1;
 		if (in->haveflags & CLK_HAVEVAL2)
 			pp->refid = in->fudgeval2;
-		if (peer->stratum <= 1)
+		peer->stratum = pp->stratum;
+		if (peer->stratum == 0)
 			peer->refid = pp->refid;
 		else
 			peer->refid = peer->srcadr.sin_addr.s_addr;
@@ -1022,7 +1017,7 @@ refclock_control(
 			CLK_HAVEVAL2 | CLK_HAVEFLAG4;
 		out->fudgetime1 = pp->fudgetime1;
 		out->fudgetime2 = pp->fudgetime2;
-		out->fudgeval1 = peer->stratum;
+		out->fudgeval1 = pp->stratum;
 		out->fudgeval2 = pp->refid;
 		out->flags = (u_char) pp->sloppyclockflag;
 
